@@ -44,6 +44,141 @@ def test_create_item_conflict(app_client, load_test_data):
     assert resp.status_code == 409
 
 
+def test_create_item_duplicate(app_client, load_test_data):
+    """Test creation of an item id which already exists but in a different collection(transactions extension)"""
+
+    # add test_item to test-collection
+    test_item = load_test_data("test_item.json")
+    resp = app_client.post(
+        f"/collections/{test_item['collection']}/items", json=test_item
+    )
+    assert resp.status_code == 200
+
+    # add test_item to test-collection again, resource already exists
+    test_item = load_test_data("test_item.json")
+    resp = app_client.post(
+        f"/collections/{test_item['collection']}/items", json=test_item
+    )
+    assert resp.status_code == 409
+
+    # create "test-collection-2"
+    collection_2 = load_test_data("test_collection.json")
+    collection_2["id"] = "test-collection-2"
+    resp = app_client.post("/collections", json=collection_2)
+    assert resp.status_code == 200
+
+    # add test_item to test-collection-2, posts successfully
+    test_item["collection"] = "test-collection-2"
+    resp = app_client.post(
+        f"/collections/{test_item['collection']}/items", json=test_item
+    )
+    assert resp.status_code == 200
+
+
+def test_delete_item_duplicate(app_client, load_test_data):
+    """Test creation of an item id which already exists but in a different collection(transactions extension)"""
+
+    # add test_item to test-collection
+    test_item = load_test_data("test_item.json")
+    resp = app_client.post(
+        f"/collections/{test_item['collection']}/items", json=test_item
+    )
+    assert resp.status_code == 200
+
+    # create "test-collection-2"
+    collection_2 = load_test_data("test_collection.json")
+    collection_2["id"] = "test-collection-2"
+    resp = app_client.post("/collections", json=collection_2)
+    assert resp.status_code == 200
+
+    # add test_item to test-collection-2
+    test_item["collection"] = "test-collection-2"
+    resp = app_client.post(
+        f"/collections/{test_item['collection']}/items", json=test_item
+    )
+    assert resp.status_code == 200
+
+    # delete test_item from test-collection
+    test_item["collection"] = "test-collection"
+    resp = app_client.delete(
+        f"/collections/{test_item['collection']}/items/{test_item['id']}"
+    )
+    assert resp.status_code == 200
+
+    # test-item in test-collection has already been deleted
+    resp = app_client.delete(
+        f"/collections/{test_item['collection']}/items/{test_item['id']}"
+    )
+    assert resp.status_code == 404
+
+    # test-item in test-collection-2 still exists, was not deleted
+    test_item["collection"] = "test-collection-2"
+    resp = app_client.post(
+        f"/collections/{test_item['collection']}/items", json=test_item
+    )
+    assert resp.status_code == 409
+
+
+def test_update_item_duplicate(app_client, load_test_data):
+    """Test creation of an item id which already exists but in a different collection(transactions extension)"""
+
+    # add test_item to test-collection
+    test_item = load_test_data("test_item.json")
+    resp = app_client.post(
+        f"/collections/{test_item['collection']}/items", json=test_item
+    )
+    assert resp.status_code == 200
+
+    # create "test-collection-2"
+    collection_2 = load_test_data("test_collection.json")
+    collection_2["id"] = "test-collection-2"
+    resp = app_client.post("/collections", json=collection_2)
+    assert resp.status_code == 200
+
+    # add test_item to test-collection-2
+    test_item["collection"] = "test-collection-2"
+    resp = app_client.post(
+        f"/collections/{test_item['collection']}/items", json=test_item
+    )
+    assert resp.status_code == 200
+
+    # update gsd in test_item, test-collection-2
+    test_item["properties"]["gsd"] = 16
+    resp = app_client.put(
+        f"/collections/{test_item['collection']}/items", json=test_item
+    )
+    assert resp.status_code == 200
+    updated_item = resp.json()
+    assert updated_item["properties"]["gsd"] == 16
+
+    # update gsd in test_item, test-collection
+    test_item["collection"] = "test-collection"
+    test_item["properties"]["gsd"] = 17
+    resp = app_client.put(
+        f"/collections/{test_item['collection']}/items", json=test_item
+    )
+    assert resp.status_code == 200
+    updated_item = resp.json()
+    assert updated_item["properties"]["gsd"] == 17
+
+    # test_item in test-collection, updated gsd = 17
+    resp = app_client.get(
+        f"/collections/{test_item['collection']}/items/{test_item['id']}"
+    )
+    assert resp.status_code == 200
+    item = resp.json()
+    assert item["properties"]["gsd"] == 17
+
+    # test_item in test-collection-2, updated gsd = 16
+    test_item["collection"] = "test-collection-2"
+    resp = app_client.get(
+        f"/collections/{test_item['collection']}/items/{test_item['id']}"
+    )
+    assert resp.status_code == 200
+    item = resp.json()
+    assert item["properties"]["gsd"] == 16
+
+
 def test_delete_missing_item(app_client, load_test_data):
     """Test deletion of an item which does not exist (transactions extension)"""
     test_item = load_test_data("test_item.json")
@@ -102,7 +237,7 @@ def test_update_item_missing_collection(app_client, load_test_data):
     resp = app_client.put(
         f"/collections/{test_item['collection']}/items", json=test_item
     )
-    assert resp.status_code == 422
+    assert resp.status_code == 404
 
 
 def test_update_item_geometry(app_client, load_test_data):
@@ -791,3 +926,23 @@ def test_conformance_classes_configurable():
     os.environ["WRITER_CONN_STRING"] = "testing"
     client = CoreCrudClient(base_conformance_classes=["this is a test"])
     assert client.conformance_classes()[0] == "this is a test"
+
+
+def test_search_datetime_validation_errors(app_client):
+    bad_datetimes = [
+        "37-01-01T12:00:27.87Z",
+        "1985-13-12T23:20:50.52Z",
+        "1985-12-32T23:20:50.52Z",
+        "1985-12-01T25:20:50.52Z",
+        "1985-12-01T00:60:50.52Z",
+        "1985-12-01T00:06:61.52Z",
+        "1990-12-31T23:59:61Z",
+        "1986-04-12T23:20:50.52Z/1985-04-12T23:20:50.52Z",
+    ]
+    for dt in bad_datetimes:
+        body = {"query": {"datetime": dt}}
+        resp = app_client.post("/search", json=body)
+        assert resp.status_code == 400
+
+        resp = app_client.get("/search?datetime={}".format(dt))
+        assert resp.status_code == 400
